--- stsoundlib/digidrum.h.orig	2016-07-26 16:04:42 UTC
+++ stsoundlib/digidrum.h
@@ -32,6 +32,8 @@
 #ifndef __DIGIDRUM__
 #define __DIGIDRUM__
 
+#define	MAX_DIGIDRUM	40
+
 extern ymu8		*	sampleAdress[];
 extern ymu32		sampleLen[];
 
