--- libgda-ui/data-entries/plugins/libmain.c.orig	2020-11-08 20:23:19 UTC
+++ libgda-ui/data-entries/plugins/libmain.c
@@ -44,6 +44,7 @@
   #endif
 
   #include <gtksourceview/gtksourceview.h>
+  #include <gtksourceview/gtksourcelanguage.h>
   #include <gtksourceview/gtksourcelanguagemanager.h>
   #include <gtksourceview/gtksourcebuffer.h>
   #include <gtksourceview/gtksourcestyleschememanager.h>
