--- src/convert_inc.c.orig	2026-05-08 22:31:14.954595000 +0200
+++ src/convert_inc.c	2026-05-08 22:31:43.230714000 +0200
@@ -108,19 +108,19 @@
 #define C_FLOAT_PCM16UNE C_FLOAT_PCM16UBE
 #define C_FLOAT_PCM32SNE C_FLOAT_PCM32SBE
 #define C_FLOAT_PCM32UNE C_FLOAT_PCM32UBE
-#define C_FLOAT_PCM24SNEPM C_FLOAT_PCM32SBEPM
-#define C_FLOAT_PCM24UNEPM C_FLOAT_PCM32UBEPM
-#define C_FLOAT_PCM24SNEPL C_FLOAT_PCM32SBEPL
-#define C_FLOAT_PCM24UNEPL C_FLOAT_PCM32UBEPL
+#define C_FLOAT_PCM24SNEPM C_FLOAT_PCM24SBEPM
+#define C_FLOAT_PCM24UNEPM C_FLOAT_PCM24UBEPM
+#define C_FLOAT_PCM24SNEPL C_FLOAT_PCM24SBEPL
+#define C_FLOAT_PCM24UNEPL C_FLOAT_PCM24UBEPL
 
 #define C_FLOAT_PCM16SOE C_FLOAT_PCM16SLE
 #define C_FLOAT_PCM16UOE C_FLOAT_PCM16ULE
 #define C_FLOAT_PCM32SOE C_FLOAT_PCM32SLE
 #define C_FLOAT_PCM32UOE C_FLOAT_PCM32ULE
-#define C_FLOAT_PCM24SOE C_FLOAT_PCM24SLEPM
-#define C_FLOAT_PCM24UOE C_FLOAT_PCM24ULEPM
-#define C_FLOAT_PCM24SOE C_FLOAT_PCM24SLEPL
-#define C_FLOAT_PCM24UOE C_FLOAT_PCM24ULEPL
+#define C_FLOAT_PCM24SOEPM C_FLOAT_PCM24SLEPM
+#define C_FLOAT_PCM24UOEPM C_FLOAT_PCM24ULEPM
+#define C_FLOAT_PCM24SOEPL C_FLOAT_PCM24SLEPL
+#define C_FLOAT_PCM24UOEPL C_FLOAT_PCM24ULEPL
 
 static void C_PCM24SLE_FLOAT(guint32 *in, FTYPE *out, int count)
 {
