--- include/cmd_line_opts.h.orig	2010-02-02 14:00:41 UTC
+++ include/cmd_line_opts.h
@@ -1,5 +1,5 @@
 #ifndef __CMD_LINE_OPTS_H__
-#define __CMD_LiNE_OPTS_H__
+#define __CMD_LINE_OPTS_H__
 
 bool co_get_int(int argc, char** argv, const char* text, int* );
 bool co_get_bool(int argc, char** argv, const char* text);
