--- src/libnova/libnova.h.orig	2015-03-03 11:16:58 UTC
+++ src/libnova/libnova.h
@@ -16,7 +16,7 @@
  *  Copyright (C) 2000 - 2005 Liam Girdwood <lgirdwood@gmail.com>
  */
 
-#define LIBNOVA_VERSION "0.15.0"
+#define LIBNOVA_VERSION "0.16.0"
 
 /*! \mainpage libnova
 * \image html libnova-logo.jpg
