From: Shengjing Zhu <shengjing.zhu@canonical.com>
Subject: Fix buffer overflow when filename contains unicode characters
Bug-Debian: https://bugs.debian.org/1077054
Bug-Debian: https://bugs.debian.org/1093629
Bug-Ubuntu: https://launchpad.net/bugs/2062535
Forwarded: https://sourceforge.net/p/infozip/bugs/81/
Origin: https://src.fedoraproject.org/rpms/zip/raw/f41/f/buffer_overflow.patch

--- fileio.c.orig	2008-05-29 00:13:24 UTC
+++ fileio.c
@@ -3502,7 +3502,7 @@ zwchar *local_to_wide_string(local_string)
   if ((wc_string = (wchar_t *)malloc((wsize + 1) * sizeof(wchar_t))) == NULL) {
     ZIPERR(ZE_MEM, "local_to_wide_string");
   }
-  wsize = mbstowcs(wc_string, local_string, strlen(local_string) + 1);
+  wsize = mbstowcs(wc_string, local_string, wsize + 1);
   wc_string[wsize] = (wchar_t) 0;
 
   /* in case wchar_t is not zwchar */
