--- include/Pheno.h.orig	2024-05-28 12:15:54 UTC
+++ include/Pheno.h
@@ -19,6 +19,7 @@
 #include <vector>
 #include <string>
 #include <map>
+#include <cstdint>
 using std::map;
 using std::vector;
 using std::string;
