--- src/libslic3r/Feature/FuzzySkin/FuzzySkin.cpp.orig	2026-03-22 17:56:38 UTC
+++ src/libslic3r/Feature/FuzzySkin/FuzzySkin.cpp
@@ -13,7 +13,7 @@
 
 #include "FuzzySkin.hpp"
 
-#include "libnoise/noise.h"
+#include "noise/noise.h"
 
 // #define DEBUG_FUZZY
 
