--- src/core/RScriptHandler.h.orig	2025-03-11 20:09:48 UTC
+++ src/core/RScriptHandler.h
@@ -25,6 +25,7 @@
 #include <QList>
 #include <QMetaType>
 #include <QString>
+#include <QScriptEngine>
 
 #include "RDocumentInterface.h"
 #include "RScriptAction.h"
