--- src_cpp/args_parser.h.orig	2021-10-01 13:09:19 UTC
+++ src_cpp/args_parser.h
@@ -52,6 +52,7 @@ goods and services.
 #include <iostream>
 #include <sstream>
 #include <assert.h>
+#include <libgen.h>
 #include <string>
 #include <map>
 #include <set>
